==> tso-auth-1.1.11-sources.jar: com/els/tso/auth/controller/UserController.java <==
package com.els.tso.auth.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.els.tso.auth.entity.User;
import com.els.tso.auth.query.UserQuery;
import com.els.tso.auth.service.IUserService;
import com.els.tso.base.util.ConvertUtil;
import com.els.tso.common.dto.R;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 * 前端控制器
 * list,one,add,delete
 * </p>
 *
 * @author daipengjie
 * @since 2020-12-31
 */
@RestController
@RequestMapping("/user")
public class UserController {

    private final IUserService userService;

    public UserController(IUserService userService) {
        this.userService = userService;
    }

    /**
     * 条件查询
     * @param query
     * @return
     */
    @GetMapping("/list")
    public R<?> list(UserQuery query) {

        //查询条件
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(ConvertUtil.copy(query, User.class));
        //分页条件
        Page<User> page = new Page<>(query.getPageNum(), query.getPageSize());
        //查询返回
        return R.ok(userService.page(page, queryWrapper));
    }

    /**
     * 单个查询
     * @param id
     * @return
     */
    @GetMapping("/one")
    public R<?> list(Long id) {

        return R.ok(userService.getById(id));
    }

    /**
     * 更新或新增
     * @param user
     * @return
     */
    @PostMapping("/save")
    public R<?> add(@RequestBody User user) {

        return R.ok(userService.saveOrUpdate(user));
    }

    /**
     * 删除
     * @param id
     * @return
     */
    @DeleteMapping("/delete")
    public R<?> delete(Long id) {

        return R.ok(userService.removeById(id));
    }


}

==> tso-auth-1.1.17-sources.jar: com/els/tso/auth/controller/UserController.java <==
package com.els.tso.auth.controller;


import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.els.tso.common.dto.R;
import com.els.tso.base.util.ConvertUtil;
import com.els.tso.auth.service.IUserService;
import com.els.tso.auth.entity.User;
import com.els.tso.auth.query.UserQuery;

/**
 * <p>
 * 用户表 前端控制器
 * </p>
 *
 * @author daipengjie
 * @since 2021-01-10
 */
@RestController
@RequestMapping("/auth/user")
public class UserController {

    private final IUserService userService;

    public UserController(IUserService userService) {
        this.userService = userService;
        }

    /**
     * 条件查询
     * @param query
     * @return
     */
    @GetMapping("/list")
    public R<?> list(UserQuery query) {

        //查询条件
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(ConvertUtil.copy(query, User.class));
        //分页条件
        Page<User> page = new Page<>(query.getPageNum(), query.getPageSize());
        //查询返回
        return R.ok(userService.page(page, queryWrapper));
        }

    /**
     * 单个查询
     * @param id
     * @return
     */
    @GetMapping("/one")
    public R<?> get(Long id) {

        return R.ok(userService.getById(id));
        }

    /**
     * 更新或新增
     * @param user
     * @return
     */
    @PostMapping
    public R<?> save(@RequestBody User user) {

        return R.ok(userService.saveOrUpdate(user));
        }

    /**
     * 删除
     * @param id
     * @return
     */
    @DeleteMapping
    public R<?> delete(Long id) {

        return R.ok(userService.removeById(id));
        }
}
